@@ -16,14 +16,14 @@ C<enable> status after login:
 To use an C<enable> password separate from the login password, add an
 C<enable_password> under C<device_auth> tag in your configuration file:
 
-device_auth:
-  - tag: sshasa
-    driver: cli
-    platform: ASA
-    only: '192.0.2.1'
-    username: oliver
-    password: letmein
-    enable_password: myenablepass
+ device_auth:
+   - tag: sshasa
+     driver: cli
+     platform: ASA
+     only: '192.0.2.1'
+     username: oliver
+     password: letmein
+     enable_password: myenablepass
 
 =cut
 
@@ -43,7 +43,7 @@ use Moo;
 Retrieve ARP and neighbor entries from device. C<$host> is the hostname or IP
 address of the device. C<$ssh> is a Net::OpenSSH connection to the device.
 
-Returns a list of hashrefs in the format C<{ mac => MACADDR, ip => IPADDR }>.
+Returns a list of hashrefs in the format C<{ mac =E<gt> MACADDR, ip =E<gt> IPADDR }>.
 
 =back
 
