@@ -20,3 +20,7 @@ def marshal_for_perl(c):
     jstr = json.dumps(retval, default=str)
     # debug('returning: ' + jstr)
     return base64.b64encode(jstr.encode('ascii')).decode('ascii')
+
+
+def piped_return(retval):
+    return base64.b64decode(retval).decode('ascii')
